function y = Froben(C,S,varargin)
% FROBEN Compute the Bregman distance of the Frobenius norm between two
% matrices.
%
%  y = Froben(C,S,varargin)
%
% It computes the Bregman distance of the Frobenius norm of C wrt S, which
% reduces simply to the halved Frobenius distance between C and S
%
%_-------------------------------------------------------------------------
% MANDATORY INPUT
%
% C        : (double array) 1st argument
% S        : (double array) 2nd argument
%
%--------------------------------------------------------------------------
% OPTIONAL INPUT
%
% varargin : not implemented, just for consistency with the other m-files.
%
% -------------------------------------------------------------------------
%
% OUTPUT
%
% y        : (double)       value of the Bregman distance
%
%==========================================================================
%
% Version : 1.0 (04-06-2019)
% Author  : A. Benfenati (alessandro.benfenati@unimi.it)
%
%==========================================================================
%
% COPYRIGHT NOTIFICATION
%
% Permission to copy and modify this software and its documentation for
% internal research use is granted, provided that this notice is retained
% thereon and on all copies or modifications. The authors and their
% respective Universities makes no representations as to the suitability
% and operability of this software for any purpose. It is provided "as is"
% without express or implied warranty. Use of this software for commercial
% purposes is expressly prohibited without contacting the authors.
%
% This program is free software; you can redistribute it and/or modify it
% under the terms of the GNU General Public License as published by the
% Free Software Foundation; either version 3 of the License, or (at your
% option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
% Public License for more details.
%
% You should have received a copy of the GNU General Public License along
% with this program; if not, either visite http://www.gnu.org/licenses/ or
% write to Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA
% 02139, USA.
%

dimC = size(C);
dimS = size(S);

% Check dimensions
if ismember(1,dimC ~= dimS | size(dimS)>2 | size(dimC)>2)
    error('Dimension not consistent');
end

y = norm(C-S,'fro');
y = 0.5*y*y;
