function y = prox_LogDet_Bounded(x, gamma,varargin)
% PROX_LOGDET_BOUNDED Compute the proximity operator of the logarithm determinant
% coupled with indicator function of [a,b].
%
% [y] = prox_LogDet_Bounded(x,gamma,varargin)
%
% This function finds the proximal point of
%
%  phi(z) = -gamma * sum( log (z) ) + i_{a,b}(z)
%
%
%--------------------------------------------------------------------------
% MANDATORY INPUT
%
% x        : (double array) argument of the prox operator
% gamma    : (double)       parameter of the proximal operator
%
%--------------------------------------------------------------------------
% OPTIONAL INPUT
%
% varargin : (double array) 2d array containing the bounds of the interval
%
%--------------------------------------------------------------------------
% OUTPUT
%
% y        : (double array) proximal point
%
%==========================================================================
%
% Version : 1.0 (04-06-2019)
% Author  : A. Benfenati (alessandro.benfenati@unimi.it)
%
%==========================================================================
%
% COPYRIGHT NOTIFICATION
%
% Permission to copy and modify this software and its documentation for
% internal research use is granted, provided that this notice is retained
% thereon and on all copies or modifications. The authors and their
% respective Universities makes no representations as to the suitability
% and operability of this software for any purpose. It is provided "as is"
% without express or implied warranty. Use of this software for commercial
% purposes is expressly prohibited without contacting the authors.
%
% This program is free software; you can redistribute it and/or modify it
% under the terms of the GNU General Public License as published by the
% Free Software Foundation; either version 3 of the License, or (at your
% option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
% Public License for more details.
%
% You should have received a copy of the GNU General Public License along
% with this program; if not, either visite http://www.gnu.org/licenses/ or
% write to Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA
% 02139, USA.
%


% check input
if any( gamma(:) <= 0 ) || ~isscalar(gamma) && any(size(gamma) ~= size(x))
    error('''gamma'' must be positive and either scalar or the same size as ''x''')
end
%-----%

a = 0;
b = 1;

if ~isempty(varargin)
    a = varargin{1}(1);
    b = varargin{1}(2);
end


y = (x ) + sqrt(x.^2 + 4*gamma);
y = y/(2);
y = min(max(a,y),b);