function y = prox_VonNeu_Schatten2(x, gamma,varargin)
% PROX_VONNEU_SCHATTEN2 Compute the proximity operator of the Von Neumann
% entropy coupled with the Schatten-2 norm.
%
% [y] = prox_VonNeu_Schatten2(x,gamma,varargin)
%
% This function finds the proximal point of
%
% phi(z) =  -gamma * sum( z * log (z) ) + gamma * mu * |z|^2
%
%
%--------------------------------------------------------------------------
% MANDATORY INPUT
%
% x        : (double array) argument of the prox operator
% gamma    : (double)       parameter of the proximal operator
%
%--------------------------------------------------------------------------
% OPTIONAL INPUT
%
% varargin : (double) further parameter
%
%--------------------------------------------------------------------------
% OUTPUT
%
% y        : (double array) proximal point
%
%==========================================================================
%
% Version : 1.0 (04-06-2019)
% Author  : A. Benfenati (alessandro.benfenati@unimi.it)
%
%==========================================================================
%
% COPYRIGHT NOTIFICATION
%
% Permission to copy and modify this software and its documentation for
% internal research use is granted, provided that this notice is retained
% thereon and on all copies or modifications. The authors and their
% respective Universities makes no representations as to the suitability
% and operability of this software for any purpose. It is provided "as is"
% without express or implied warranty. Use of this software for commercial
% purposes is expressly prohibited without contacting the authors.
%
% This program is free software; you can redistribute it and/or modify it
% under the terms of the GNU General Public License as published by the
% Free Software Foundation; either version 3 of the License, or (at your
% option) any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General
% Public License for more details.
%
% You should have received a copy of the GNU General Public License along
% with this program; if not, either visite http://www.gnu.org/licenses/ or
% write to Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA
% 02139, USA.
%

mu = 0;

if ~isempty(varargin)
    mu = varargin{1}(1);
end


y = exp((x-gamma)/gamma);
y = (2*mu+1)/gamma * y;
y = lambertw(y);
y = gamma/(2*mu+1)*y;
y = min(max(0,y),realmax);